@@ -8,10 +8,3 @@ ENV_FILE = os.path.abspath('.env')
 CID10_FILE = os.path.abspath('metadoctor/cid10.csv')
 
 config = Config(env_file=ENV_FILE)
-
-
-
-
-if __name__ == '__main__':
-    print(CID10_FILE)
-    
\ No newline at end of file
